Index: trunk/MagicSoft/include-Classes/MRawEvt.cxx
===================================================================
--- trunk/MagicSoft/include-Classes/MRawEvt.cxx	(revision 370)
+++ trunk/MagicSoft/include-Classes/MRawEvt.cxx	(revision 371)
@@ -22,5 +22,5 @@
 // ----------
 //
-// UInt_t    uiEvtNo    
+// UInt_t    EvtNo    
 //
 // This it the number of the Event in one 
@@ -37,5 +37,5 @@
 // ----------
 //
-// ULong_t   ulTimeStamp
+// ULong_t   TimeStamp
 //   
 // Time of the event. 
@@ -49,5 +49,5 @@
 // ----------
 //
-// UChar_t   ucEvtStatus 
+// UChar_t   EvtStatus 
 //
 // Status of Event. 
@@ -57,5 +57,5 @@
 // ----------
 //
-// UShort_t  usTrig1st
+// UShort_t  Trig1st
 //
 // Number of first level trigger
@@ -70,5 +70,5 @@
 // ----------
 //
-// UShort_t  usMultPixel
+// UShort_t  MultPixel
 //
 // Multiplicity of Pixels
@@ -80,5 +80,5 @@
 // ----------
 //
-// TClonesArray  *taPixels
+// TClonesArray  *Pixels
 //
 // Array of Pixels 
@@ -108,9 +108,9 @@
   //   set all member to zero, init the pointer to ClonesArray, 
 
-  uiEvtNo      = 0 ; 
-  ulTimeStamp  = 0 ; 
-  ucEvtStatus  = 0 ; 
-  usTrig1st    = 0 ;
-  usMultPixel  = 0 ; 
+  EvtNo      = 0 ; 
+  TimeStamp  = 0 ; 
+  EvtStatus  = 0 ; 
+  Trig1st    = 0 ;
+  MultPixel  = 0 ; 
 
   // 
@@ -120,5 +120,5 @@
   //   initialize the list to this global pointer
   
-  taPixels = new TClonesArray ("MRawPixel", 2*CAMERA_PIXELS ) ; 
+  Pixels = new TClonesArray ("MRawPixel", 2*CAMERA_PIXELS ) ; 
 
   cout << " default constructor " << endl ; 
@@ -130,5 +130,5 @@
   //   Implementation of the default destructor
   //
-  delete taPixels ; 
+  delete Pixels ; 
   cout << " default destructor " << endl ; 
 }
@@ -140,11 +140,11 @@
   //   Resets all members to zero, clear the list of Pixels
   //
-  uiEvtNo      = 0 ; 
-  ulTimeStamp  = 0 ; 
-  ucEvtStatus  = 0 ; 
-  usTrig1st    = 0 ;
-  usMultPixel  = 0 ; 
-
-  taPixels->Clear() ; 
+  EvtNo      = 0 ; 
+  TimeStamp  = 0 ; 
+  EvtStatus  = 0 ; 
+  Trig1st    = 0 ;
+  MultPixel  = 0 ; 
+
+  Pixels->Clear() ; 
 }
 
@@ -157,12 +157,12 @@
 
   // Prints out the data of one Pixel
-  cout << endl << "EventNumber      " << uiEvtNo          ; 
-  cout << endl << "Event Time Stamp " << ulTimeStamp      ;
-  cout << endl << "Event Status     " << (int) ucEvtStatus      ; 
-  cout << endl << "Trigger 1. Level " << usTrig1st        ; 
-  cout << endl << "Number of Pixels " << usMultPixel      ; 
-
-  for (Int_t i=0 ; i<usMultPixel; i++ ) {
-    ((MRawPixel *)taPixels->At(i))->Print() ;    
+  cout << endl << "EventNumber      " << EvtNo          ; 
+  cout << endl << "Event Time Stamp " << TimeStamp      ;
+  cout << endl << "Event Status     " << (int) EvtStatus      ; 
+  cout << endl << "Trigger 1. Level " << Trig1st        ; 
+  cout << endl << "Number of Pixels " << MultPixel      ; 
+
+  for (Int_t i=0 ; i<MultPixel; i++ ) {
+    ((MRawPixel *)Pixels->At(i))->Print() ;    
   }
 }
@@ -176,6 +176,6 @@
   // 
 
-  uiEvtNo      = uiN ; 
-  ulTimeStamp  = ulT ; 
+  EvtNo      = uiN ; 
+  TimeStamp  = ulT ; 
 
   UChar_t   ucA[FADC_SLICES] ;
@@ -184,6 +184,6 @@
     GetFadcNoise ( ucA ) ;   
   
-    TClonesArray &caP = *taPixels ;
-    new ( caP[usMultPixel++] ) MRawPixel((usMultPixel), 0, ucA) ; 
+    TClonesArray &caP = *Pixels ;
+    new ( caP[MultPixel++] ) MRawPixel((MultPixel), 0, ucA) ; 
   }
 }
@@ -191,12 +191,12 @@
 void MRawEvt::FillHeader ( UInt_t uiN, ULong_t ulT ) {
    
-  uiEvtNo      = uiN ; 
-  ulTimeStamp  = ulT ; 
-  
-  ucEvtStatus  = 0 ; 
-  usTrig1st    = 0 ;
-  usMultPixel  = 0   ; 
-
-  taPixels->Clear()  ; 
+  EvtNo      = uiN ; 
+  TimeStamp  = ulT ; 
+  
+  EvtStatus  = 0 ; 
+  Trig1st    = 0 ;
+  MultPixel  = 0   ; 
+
+  Pixels->Clear()  ; 
 }
 
@@ -213,6 +213,6 @@
   } 
   
-  TClonesArray &caP = *taPixels ;
-  new ( caP[usMultPixel++] ) MRawPixel((uiPix), 0, ucA) ; 
+  TClonesArray &caP = *Pixels ;
+  new ( caP[MultPixel++] ) MRawPixel((uiPix), 0, ucA) ; 
 }
 
@@ -224,8 +224,8 @@
   // 
 
-  uiEvtNo      = uiN ; 
-  ulTimeStamp  = ulT ; 
-
-  usMultPixel = 0 ; 
+  EvtNo      = uiN ; 
+  TimeStamp  = ulT ; 
+
+  MultPixel = 0 ; 
 
   UChar_t   ucA[FADC_SLICES] ;
@@ -239,6 +239,6 @@
       ucA[5] = (UShort_t) (array[i]) ; 
       
-      TClonesArray &caP = *taPixels ;
-      new ( caP[usMultPixel++] ) MRawPixel(i, 0, ucA) ; 
+      TClonesArray &caP = *Pixels ;
+      new ( caP[MultPixel++] ) MRawPixel(i, 0, ucA) ; 
     }
   }
@@ -249,5 +249,5 @@
   //  returns the pixel multiplicity of the Event
   //
-  return usMultPixel;
+  return MultPixel;
 }
 
Index: trunk/MagicSoft/include-Classes/MRawEvt.h
===================================================================
--- trunk/MagicSoft/include-Classes/MRawEvt.h	(revision 370)
+++ trunk/MagicSoft/include-Classes/MRawEvt.h	(revision 371)
@@ -11,15 +11,15 @@
 
  private: 
-  UInt_t        uiEvtNo     ;  // Number of Event
+  UInt_t        EvtNo     ;  // Number of Event
 
-  ULong_t       ulTimeStamp ;  // Time of the Event
+  ULong_t       TimeStamp ;  // Time of the Event
 
-  UChar_t       ucEvtStatus ;  // Status of this event (DAQ, Pedestal, ..) 
+  UChar_t       EvtStatus ;  // Status of this event (DAQ, Pedestal, ..) 
  
-  UShort_t      usTrig1st   ;  // Number of 1st level tiggers between 2 events
+  UShort_t      Trig1st   ;  // Number of 1st level tiggers between 2 events
 
-  UShort_t      usMultPixel ;  // Multiplicity of the Pixels in this event   
+  UShort_t      MultPixel ;  // Multiplicity of the Pixels in this event   
 
-  TClonesArray  *taPixels   ;  // list of the events
+  TClonesArray  *Pixels   ;  // list of the events
 
  public: 
@@ -47,5 +47,5 @@
   //   returns a Pointer to the pixel list
   //
-  return  taPixels ;
+  return  Pixels ;
 }
 
Index: trunk/MagicSoft/include-Classes/MRawPixel.h
===================================================================
--- trunk/MagicSoft/include-Classes/MRawPixel.h	(revision 370)
+++ trunk/MagicSoft/include-Classes/MRawPixel.h	(revision 371)
@@ -13,9 +13,9 @@
  private: 
 
-  UShort_t     usPixelId     ;           //  Identification of PixelNumber and gain branch
+  UShort_t     PixelId     ;           //  Identification of PixelNumber and gain branch
 
-  UChar_t      ucPixelStatus ;           //  The Status of the pixel
+  UChar_t      PixelStatus ;           //  The Status of the pixel
 
-  UChar_t      aucFadc[ FADC_SLICES ]  ; // The values of fadc-slices.
+  UChar_t      Fadc[ FADC_SLICES ]  ;  // The values of fadc-slices.
 
  public:

Index: trunk/MagicSoft/include-Classes/MRawPixel.cxx
===================================================================
--- trunk/MagicSoft/include-Classes/MRawPixel.cxx	(revision 370)
+++ trunk/MagicSoft/include-Classes/MRawPixel.cxx	(revision 371)
@@ -26,5 +26,5 @@
 // ---------
 //
-// UShort_t     usPixelId     ;   
+// UShort_t     PixelId     ;   
 //
 // This is to identify the Pixel.
@@ -34,26 +34,26 @@
 // To reduce the amount of data, we store the information of the 
 // low-gain-branch of the Fadc´s only if there is a signal in. Then the 
-// usPixelId is:
-//                   usPixelId = 10000 + PixelId   . 
+// PixelId is:
+//                   PixelId = 10000 + PixelId   . 
 //
 // For the high gain Fadc values the rule is:
-//                   usPixelId = PixelId . 
+//                   PixelId = PixelId . 
 //
 //
 // ---------
 //
-// UChar_t      ucPixelStatus ;   
+// UChar_t      PixelStatus ;   
 //
 // The PixelStatus may contain information if the Pixel has triggered 
 // this event. Also the kind of gain-branch (high or low) may be indicated 
 // by one bit of the ucPixelStatus. etc
 //
 // ---------
 //
-// UChar_t      aucFadc[ FADC_SLICES ]  ; 
+// UChar_t      Fadc[ FADC_SLICES ]  ; 
 //
 // The values of FADC_SLICES fadc-slices. This is the information of the 
 // measured ADC values for one branch (high gain or low gain). The typ of 
 // branch is indicated in the usPixelNumber and in the ucPixelStatus.
 
 ClassImp(MRawPixel) 
@@ -66,9 +66,9 @@
   //
     
-    usPixelId     = 0 ; 
-    ucPixelStatus = 0 ; 
+    PixelId     = 0 ; 
+    PixelStatus = 0 ; 
     
     for (Int_t i = 0; i<FADC_SLICES; i++) 
-      aucFadc[i]   = 0 ; 
+      Fadc[i]   = 0 ; 
 }
 
@@ -80,9 +80,9 @@
   //  Parameter is the PixelId. All other data member are set to zero
   
-  usPixelId     = PId ; 
-  ucPixelStatus = 0 ; 
+  PixelId     = PId ; 
+  PixelStatus = 0 ; 
   
   for (Int_t i = 0; i<FADC_SLICES; i++) 
-    aucFadc[i]   = 0 ; 
+    Fadc[i]   = 0 ; 
 }
 
@@ -94,9 +94,9 @@
   // parameters are PixelId, Status and an array with Fadc numbers.
   
-  usPixelId     = usPId ; 
-  ucPixelStatus = ucSt  ; 
+  PixelId     = usPId ; 
+  PixelStatus = ucSt  ; 
   
   for (Int_t i = 0; i<FADC_SLICES; i++) 
-    aucFadc[i]   = ucF[i] ; 
+    Fadc[i]   = ucF[i] ; 
 }
 MRawPixel::~MRawPixel(){
@@ -110,9 +110,9 @@
   //  Sets the data member back to zero
   //
-  usPixelId     = 0 ; 
-  ucPixelStatus = 0 ; 
+  PixelId     = 0 ; 
+  PixelStatus = 0 ; 
   
   for (Int_t i = 0; i<FADC_SLICES; i++) 
-    aucFadc[i]   = 0 ; 
+    Fadc[i]   = 0 ; 
 } 
 
@@ -124,9 +124,9 @@
   //
 
-  cout << endl << "PixId " << usPixelId          ; 
-  cout << " Stat " << (Int_t) ucPixelStatus << " --> "     ;
+  cout << endl << "PixId " << PixelId          ; 
+  cout << " Stat " << (Int_t) PixelStatus << " --> "     ;
 
   for (Int_t i=0 ; i<FADC_SLICES ; i++ ) {
-    cout<<" / " << (int) aucFadc[i] ; 
+    cout<<" / " << (int) Fadc[i] ; 
   } 
 }
@@ -136,5 +136,5 @@
   // returns back the PixelId of the Pixel
   //
-  return usPixelId;
+  return PixelId;
 }
 
@@ -143,5 +143,5 @@
   // returns back the fadc content of the slice iSli 
   //
-  return ( aucFadc[iSli] ) ; 
+  return ( Fadc[iSli] ) ; 
 }
 
@@ -34,26 +34,26 @@
 // The PixelStatus may contain information if the Pixel has triggered 
 // this event. Also the kind of gain-branch (high or low) may be indicated 
-// by one bit of the ucPixelStatus. etc
+// by one bit of the PixelStatus. etc
 //
 // ---------
@@ -34,26 +34,26 @@
 // The values of FADC_SLICES fadc-slices. This is the information of the 
 // measured ADC values for one branch (high gain or low gain). The typ of 
-// branch is indicated in the usPixelNumber and in the ucPixelStatus.
+// branch is indicated in the usPixelNumber and in the PixelStatus.
 
 ClassImp(MRawPixel) 